<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// I
	'icone_repartition_actuelle' => 'نمايش توزيع كنونى',
	'icone_repartition_visites' => 'نمودار بازديدها',
	'icone_statistiques_visites' => 'آمار بازديد كنندگان',
	'info_popularite_5' => ': محبوبيت',
	'info_visites' => ':بازديد ',
	'info_zoom' => 'زوم',

	// O
	'onglet_origine_visites' => 'ده‌سپیکو سه‌ردانییه‌ ناوخوییه‌کا',
	'onglet_repartition_debut' => 'چه‌ کاتو ده‌سپنه‌که‌رده‌یۆ',
	'onglet_repartition_lang' => 'به‌ زڤانی',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'titre_liens_entrants' => 'به‌سته‌رى لڤایچووه‌ری',
];
